@@ -177,7 +177,7 @@ func Test_parseOutputFlag(t *testing.T) {
 				out: "",
 			},
 			want: nil,
-			err:  fmt.Errorf("Unable to parse output flag '': \nAccepted formats are: console://,json://PATH/TO/FILE.json"),
+			err:  fmt.Errorf("Unable to parse output flag '': \nAccepted formats are: console://,html://PATH/TO/FILE.html,json://PATH/TO/FILE.json"),
 		},
 		{
 			name: "test invalid",
@@ -185,7 +185,7 @@ func Test_parseOutputFlag(t *testing.T) {
 				out: "sdgjsdgjsdg",
 			},
 			want: nil,
-			err:  fmt.Errorf("Unable to parse output flag 'sdgjsdgjsdg': \nAccepted formats are: console://,json://PATH/TO/FILE.json"),
+			err:  fmt.Errorf("Unable to parse output flag 'sdgjsdgjsdg': \nAccepted formats are: console://,html://PATH/TO/FILE.html,json://PATH/TO/FILE.json"),
 		},
 		{
 			name: "test invalid",
@@ -193,7 +193,7 @@ func Test_parseOutputFlag(t *testing.T) {
 				out: "://",
 			},
 			want: nil,
-			err:  fmt.Errorf("Unable to parse output flag '://': \nAccepted formats are: console://,json://PATH/TO/FILE.json"),
+			err:  fmt.Errorf("Unable to parse output flag '://': \nAccepted formats are: console://,html://PATH/TO/FILE.html,json://PATH/TO/FILE.json"),
 		},
 		{
 			name: "test unsupported",
@@ -201,7 +201,7 @@ func Test_parseOutputFlag(t *testing.T) {
 				out: "foobar://",
 			},
 			want: nil,
-			err:  fmt.Errorf("Unsupported output 'foobar': \nValid formats are: console://,json://PATH/TO/FILE.json"),
+			err:  fmt.Errorf("Unsupported output 'foobar': \nValid formats are: console://,html://PATH/TO/FILE.html,json://PATH/TO/FILE.json"),
 		},
 		{
 			name: "test empty json",
