@@ -32,6 +32,7 @@ type ScanOptions struct {
 	ProviderVersion  string
 	ConfigDir        string
 	DriftignorePath  string
+	Deep             bool
 }
 
 type DriftCTL struct {
@@ -58,7 +59,7 @@ func NewDriftCTL(remoteSupplier resource.Supplier,
 		remoteSupplier,
 		iacSupplier,
 		alerter,
-		analyser.NewAnalyzer(alerter),
+		analyser.NewAnalyzer(alerter, analyser.AnalyzerOptions{Deep: opts.Deep}),
 		resFactory,
 		scanProgress,
 		iacProgress,
@@ -128,12 +129,13 @@ func (d DriftCTL) Run() (*analyser.Analysis, error) {
 	driftIgnore := filter.NewDriftIgnore(d.opts.DriftignorePath)
 
 	analysis, err := d.analyzer.Analyze(remoteResources, resourcesFromState, driftIgnore)
-	analysis.Duration = time.Since(start)
-
 	if err != nil {
 		return nil, err
 	}
 
+	analysis.Duration = time.Since(start)
+	analysis.Date = time.Now()
+
 	return &analysis, nil
 }
 
