@@ -1,7 +1,7 @@
 package enumerator
 
 import (
-	"path/filepath"
+	"fmt"
 	"strings"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -43,7 +43,10 @@ func (s *S3Enumerator) Enumerate() ([]string, error) {
 	bucket := bucketPath[0]
 	prefix, pattern := GlobS3(strings.Join(bucketPath[1:], "/"))
 
-	fullPattern := filepath.Join(prefix, pattern)
+	fullPattern := prefix
+	if pattern != "" {
+		fullPattern = strings.Join([]string{prefix, pattern}, "/")
+	}
 
 	files := make([]string, 0)
 	input := &s3.ListObjectsV2Input{
@@ -55,7 +58,7 @@ func (s *S3Enumerator) Enumerate() ([]string, error) {
 			if aws.Int64Value(metadata.Size) > 0 {
 				key := *metadata.Key
 				if match, _ := doublestar.Match(fullPattern, key); match {
-					files = append(files, filepath.Join(bucket, key))
+					files = append(files, strings.Join([]string{bucket, key}, "/"))
 				}
 			}
 		}
@@ -65,5 +68,9 @@ func (s *S3Enumerator) Enumerate() ([]string, error) {
 		return nil, err
 	}
 
+	if len(files) == 0 {
+		return files, fmt.Errorf("no Terraform state was found in %s, exiting", s.config.Path)
+	}
+
 	return files, nil
 }
