@@ -44,7 +44,7 @@ func TestS3BucketPolicySupplier_Resources(t *testing.T) {
 
 				repository.On(
 					"GetBucketLocation",
-					&s3.Bucket{Name: awssdk.String("dritftctl-test-no-policy")},
+					"dritftctl-test-no-policy",
 				).Return(
 					"eu-west-3",
 					nil,
@@ -64,7 +64,7 @@ func TestS3BucketPolicySupplier_Resources(t *testing.T) {
 
 				repository.On(
 					"GetBucketLocation",
-					&s3.Bucket{Name: awssdk.String("bucket-martin-test-drift")},
+					"bucket-martin-test-drift",
 				).Return(
 					"eu-west-1",
 					nil,
@@ -72,7 +72,7 @@ func TestS3BucketPolicySupplier_Resources(t *testing.T) {
 
 				repository.On(
 					"GetBucketLocation",
-					&s3.Bucket{Name: awssdk.String("bucket-martin-test-drift2")},
+					"bucket-martin-test-drift2",
 				).Return(
 					"eu-west-3",
 					nil,
@@ -80,7 +80,7 @@ func TestS3BucketPolicySupplier_Resources(t *testing.T) {
 
 				repository.On(
 					"GetBucketLocation",
-					&s3.Bucket{Name: awssdk.String("bucket-martin-test-drift3")},
+					"bucket-martin-test-drift3",
 				).Return(
 					"ap-northeast-1",
 					nil,
