@@ -9,7 +9,8 @@ import (
 
 func TestAcc_AwsNATGateway(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
-		Paths: []string{"./testdata/acc/aws_nat_gateway"},
+		TerraformVersion: "0.14.9",
+		Paths:            []string{"./testdata/acc/aws_nat_gateway"},
 		// We filter on aws_eip_association too to test the middleware behavior
 		Args: []string{"scan", "--filter", "Type=='aws_nat_gateway' || Type=='aws_eip_association'"},
 		Checks: []acceptance.AccCheck{
@@ -22,7 +23,7 @@ func TestAcc_AwsNATGateway(t *testing.T) {
 						t.Fatal(err)
 					}
 					result.AssertInfrastructureIsInSync()
-					result.Equal(1, result.Summary().TotalManaged)
+					result.AssertManagedCount(1)
 				},
 			},
 		},
